<?php

namespace Drupal\shortify\AdditionalClass;

use Drupal;

class SettingsGenerator
{
    public static function generateTabsFromSettings($settings): string
    {
        $html = '';
        foreach ($settings as $key => $value) {
            $class = $key == 0 ? 'actived' : '';
            $html .= "<div data-id='$key' class='content-tab $class'><p>{$value["description"]}</p><div class='elements'>" . self::generateTabElements($value["elements"], $key) . "</div></div>";
        }
        return $html;
    }

    public static function generateTabElements($elements, $mainKey): string
    {
        $html = '';
        foreach ($elements as $key => $value) {
            $type = $value["type"];
            $name = $value["name"];
            $val = $value["value"] ?? '';
            $width = "ps_element_width-" . ($value["width"] ?? "100");
            $id = "el-" . $mainKey . "-" . $key;

            switch ($type) {
                case "textarea":
                    $ctx = "<textarea id='$id' data-parent='$mainKey' data-id='$key' class='content-input'>$val</textarea>";
                    $html .= "<div class='element $width'><label for='$id'>$name</label>$ctx</div>";
                    break;
                case "html":
                    $ctx = "<textarea id='$id' data-parent='$mainKey' data-id='$key' class='content-input html_editor_quill'>$val</textarea>";
                    $html .= "<div class='element $width'><label for='$id'>$name</label>$ctx</div>";
                    break;
                case "checkbox":
                    $val = $val == "true" ? "checked='checked'" : "";
                    $ctx = "<input id='$id' data-parent='$mainKey' data-id='$key' $val class='content-input' type='checkbox'/><div class='control__indicator'></div>";
                    $html .= "<div class='element $width'><label class='control control--checkbox' for='$id'>$name$ctx</label></div>";
                    break;
                case "text":
                    $ctx = "<input id='$id' data-parent='$mainKey' data-id='$key' value='$val' class='content-input' type='text'/>";
                    $html .= "<div class='element $width'><label for='$id'>$name</label>$ctx</div>";
                    break;
                case "color":
                    $ctx = "<input id='$id' data-parent='$mainKey' data-id='$key' value='$val' class='content-input' type='color'/>";
                    $html .= "<div class='element $width'><label for='$id'>$name</label>$ctx</div>";
                    break;
                case "icon":
                    $icon = (isset($val) && strlen($val) > 0) ? "<i class='$val'></i>" : "";
                    $ctx = "<div id='$id' data-icon='$val' data-parent='$mainKey' data-id='$key'  class='content-input' type='icon'>$icon</div><button class='select-icon-button-in-element'>Select icon</button><div class='select-icon-button-remove'><i class='fas fa-times'></i></div>";
                    $html .= "<div class='element $width element-with-icon-select'><label for='$id'>$name</label>$ctx</div>";
                    break;
                case "number":
                    $ctx = "<input id='$id' data-parent='$mainKey' data-id='$key' value='$val' class='content-input' type='number'/>";
                    $html .= "<div class='element $width'><label for='$id'>$name</label>$ctx</div>";
                    break;
                case "file":
                    $word = t('Select a file...');
                    $wordTrans = t('Select a file...');
                    $accept = $value["accept"] ?? "";
                    $accept = strlen($accept) > 1 ? "accept='" . $accept . "'" : "";

                    if (strlen($val) > 4) {
                        $valueArray = explode("/", $val);
                        $word = $valueArray[count($valueArray) - 1];
                    }
                    $ctx = "<div class='input-file-container'>
                      <input class='content-input input-file' type='file' $accept style='opacity: 0; visibility: hidden'/>
                      <input id='$id' data-parent='$mainKey' data-id='$key' value='$val' type='hidden'/>
                      <label data-name='$wordTrans' tabindex='0' for='$id' class='input-file-trigger'>$word</label>
                      <div class='select-file-button-remove'><i class='fas fa-times'></i></div>
                    </div>";
                    $html .= "<div class='element $width'><label for='$id'>$name</label>$ctx</div>";
                    break;
                case "file_list":
                    $word = t('Select one file or more...');
                    $wordTrans = t('Add file...');
                    $accept = $value['accept'] ?? "";
                    $accept = strlen($accept) > 1 ? "accept='" . $accept . "'" : "";
                    $value = '';

                    if (strlen($val) > 4) {
                        $valueArray = explode("{|#|}", $val);
                        foreach ($valueArray as $oneValue) {
                            $fileId = explode("{#}", $oneValue)[0];
                            $fileName = explode("{#}", $oneValue)[1];
                            if (strlen($fileId) > 0 && strlen($fileName) > 0) {
                                $value .= "<div class='file-single-element'>
                                        <span id='file-id-$fileId' class='file-label-name'>$fileName</span>
                                        <div class='select-file-multi-button-remove'><i class='far fa-trash-alt'></i></div>
                                    </div>";
                            }
                        }
                    }

                    $ctx = "<div class='input-file-multi-container'>
                                <input class='content-input input-file-multi' type='file' multiple='multiple' $accept style='opacity: 0; visibility: hidden'/>
                                <input id='$id' data-parent='$mainKey' data-id='$key' value='$val' type='hidden'/>
                                <label data-name='$wordTrans' tabindex='0' for='$id' class='input-file-multi-trigger'>$word</label>
                                <div class='input-file-multi-content'> 
                                  $value
                                </div>
                            </div>";
                    $html .= "<div class='element $width'><label for='$id'>$name</label>$ctx</div>";
                    break;
                case "select":
                    $word = t('none');
                    $ctx = "<select id='$id' data-parent='$mainKey' data-id='$key'><option value=''>$word</option>";
                    foreach ($value["select_list"] as $keyIn => $valueIn) {
                        $ctx .= $keyIn === $val
                            ? "<option value='$keyIn' selected>$valueIn</option>"
                            : "<option value='$keyIn'>$valueIn</option>";
                    }
                    $ctx .= "</select>";
                    $html .= "<div class='element ps-custom-select $width'><label for='$id'>$name</label>$ctx</div>";
                    break;
            }
        }
        return $html;
    }

    public static function basicSettings($token = NULL) : array
    {
        $settings = [
            "elements" => [
                [
                    "tabName" => t("Main config"),
                    "description" => t("Main element config."),
                    "elements" => [],
                ],
                [
                    "tabName" => t("Size"),
                    "description" => t("Define element size."),
                    "elements" => [
                        [
                            "type" => "number",
                            "name" => t("padding left"),
                            "width" => "25",
                            "value" => "",
                        ],
                        [
                            "type" => "number",
                            "name" => t("padding right"),
                            "width" => "25",
                            "value" => "",
                        ],
                        [
                            "type" => "number",
                            "name" => t("padding top"),
                            "width" => "25",
                            "value" => "",
                        ],
                        [
                            "type" => "number",
                            "name" => t("padding bottom"),
                            "width" => "25",
                            "value" => "",
                        ],
                        [
                            "type" => "number",
                            "name" => t("margin left"),
                            "width" => "25",
                            "value" => "",
                        ],
                        [
                            "type" => "number",
                            "name" => t("margin right"),
                            "width" => "25",
                            "value" => "",
                        ],
                        [
                            "type" => "number",
                            "name" => t("margin top"),
                            "width" => "25",
                            "value" => "",
                        ],
                        [
                            "type" => "number",
                            "name" => t("margin bottom"),
                            "width" => "25",
                            "value" => "",
                        ],
                    ],
                ],
                [
                    "tabName" => t("Customize"),
                    "description" => t("Define additional class, id, styles and others."),
                    "elements" => [
                        [
                            "type" => "text",
                            "name" => t("additional class"),
                            "width" => "50",
                            "value" => "",
                        ],
                        [
                            "type" => "text",
                            "name" => t("element id"),
                            "width" => "50",
                            "value" => "",
                        ],
                        [
                            "type" => "colorpicker",
                            "name" => t("background color"),
                            "atr_name" => "background_color",
                            "width" => "50",
                            "value" => "",
                        ],
                        [
                            "type" => "textarea",
                            "name" => t("container styles"),
                            "atr_name" => "additional_styles",
                            "width" => "50",
                            "value" => "",
                        ],
                    ],
                ],
                [
                    "tabName" => t("Animations"),
                    "description" => t("Specify if, and how, an object should animate. You have a choice of several animations and its parameters. Animation determines how the object will appear or behave."),
                    "elements" => [
                        [
                            "type" => "select",
                            "atr_name" => "animation_name",
                            "name" => t("Animation"),
                            "width" => "50",
                            "select_type" => "list",
                            "select_list" =>  AvailableAnimations::getAnimationList(),
                            "value" => "none",
                        ],
                        [
                            "type" => "number",
                            "atr_name" => "animation_duration",
                            "name" => t("Animation duration (ms)"),
                            "width" => "25",
                            "value" => "500",
                        ],
                        [
                            "type" => "number",
                            "atr_name" => "animation_delay",
                            "name" => t("Animation delay (ms)"),
                            "width" => "25",
                            "value" => "0",
                        ],
                        [
                            "type" => "select",
                            "atr_name" => "hover_class",
                            "name" => t("Effect on hover"),
                            "width" => "50",
                            "select_type" => "list",
                            "select_list" => AvailableAnimations::getHoverList(),
                            "value" => "",
                        ],
                    ],
                ],
                [
                    "tabName" => t("Others"),
                    "description" => t("Additional configuration"),
                    "elements" => [
                        [
                            "type" => "checkbox",
                            "atr_name" => "ps_cache",
                            "name" => t("Should the item be cached?"),
                            "width" => "100",
                            "value" => "false",
                        ],
                        [
                            "type" => "checkbox",
                            "atr_name" => "is_shadow",
                            "name" => t("Drop shadow?"),
                            "width" => "25",
                            "value" => "false",
                        ],
                    ],
                ],
            ],
        ];

        if (!is_null($token)) {
            $shortcodeService = Drupal::service('shortcode');
            $shortcodes = $shortcodeService->loadShortcodePlugins();
            $settings["elements"][0]["elements"] = $shortcodes[$token]["settings"];
        }

        return $settings;
    }
}