<?php

namespace Drupal\shortify\Controller;

use Drupal;
use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityStorageException;
use Drupal\Core\File\FileSystemInterface;
use Drupal\shortify\AdditionalClass\AvailableIcons;
use Drupal\shortify\AdditionalClass\Helpers\ShortcodeHelper;
use Drupal\shortify\AdditionalClass\SettingsGenerator;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Symfony\Component\HttpFoundation\Response;

class ShortifyController extends ControllerBase implements ContainerInjectionInterface
{
    public function getAvailableIconList() : JsonResponse
    {
        return new JsonResponse(AvailableIcons::getFontAwesomeIcons());
    }

    public function getElementSettingsInHTML(Request $request) : Response
    {
        $token = $_POST["token"] ?? '';
        $settings = isset($_POST["settings"]) ? json_decode($_POST["settings"], TRUE) : [];

        if (strlen($token) <= 2) {
            return new Response(\GuzzleHttp\json_encode([
                "data" => t("Invalid token"),
                "error" => TRUE,
            ]));
        }

        $html = "<div class='shortcode-modal-settings-content'><div class='tabs'><ul>";

        foreach ($settings as $key => $value) {
            $class = $key == 0 ? 'actived' : '';
            $html .= "<li data-id='$key' class='$class'>{$value["tabName"]}</li>";
        }
        $html .= "</ul></div>
            <div class='content'>
                " . SettingsGenerator::generateTabsFromSettings($settings) . "
            </div>
        </div>";


        return new Response(\GuzzleHttp\json_encode([
            "data" => $html,
            "error" => FALSE,
        ]));
    }

    public function deleteFile() : JsonResponse
    {
        if (isset($_POST['id'])) {
            $id = $_POST['id'];

            try {
                $fileStorageHandler = Drupal::entityTypeManager()
                    ->getStorage("file");
                $file = $fileStorageHandler->load($id);

                if($file)
                    $file->delete();
            } catch (EntityStorageException | InvalidPluginDefinitionException | PluginNotFoundException $e){
                return new JsonResponse(['id' => 0]);
            }

            return new JsonResponse(['id' => $id]);
        }

        return new JsonResponse(['id' => 0]);
    }

    public function getShortcodesFilteredByParent() : Response
    {
        $parentName = $_POST["parent"] ?? '';

        $defaultList = ShortcodeHelper::getDefaultShortcodeList();
        $parentConfig = ShortcodeHelper::getParentConfig($parentName);

        for ($j = count($defaultList) - 1; $j >= 0; $j--) {
            for ($i = count($defaultList[$j]['elements']) - 1; $i >= 0; $i--) {
                if ($defaultList[$j]['elements'][$i]['id'] === $parentName) {
                    array_splice($defaultList[$j]['elements'], $i, 1);
                    continue;
                }
                if (!is_null($parentConfig) && isset($parentConfig['child']) && count($parentConfig['child']) > 0) {
                    $isIn = FALSE;
                    foreach ($parentConfig['child'] as $dependency) {
                        if ($defaultList[$j]['elements'][$i]['id'] === $dependency) {
                            $isIn = TRUE;
                            break;
                        }
                    }
                    if (!$isIn) {
                        array_splice($defaultList[$j]['elements'], $i, 1);
                        continue;
                    }
                }
                if (isset($defaultList[$j]['elements'][$i]['dependency']['parent']) && count($defaultList[$j]['elements'][$i]['dependency']['parent']) > 0) {

                    $isIn = FALSE;
                    foreach ($defaultList[$j]['elements'][$i]['dependency']['parent'] as $dependency) {
                        if ($parentName === $dependency) {
                            $isIn = TRUE;
                            break;
                        }
                    }

                    if (!$isIn) {
                        array_splice($defaultList[$j]['elements'], $i, 1);
                    }
                }
            }
        }

        return new Response(\GuzzleHttp\json_encode($defaultList));
    }

    public function addFile() : JsonResponse
    {
        if (isset($_FILES['files']['name'])) {
            $last = $_POST['last'] ?? '';

            if ($last && strlen($last) > 4) {
                $fileId = explode("{#}", $last, 1)[0];

                try {
                    $fileStorageHandler = Drupal::entityTypeManager()
                        ->getStorage("file");
                    $file = $fileStorageHandler->load($fileId);

                    if($file)
                        $file->delete();
                } catch (EntityStorageException | InvalidPluginDefinitionException | PluginNotFoundException $e){}
            }
            $validators = ['file_validate_extensions' => ''];

            $file = file_save_upload('image', $validators, 'public://', FileSystemInterface::EXISTS_RENAME);

            if ($file) {
                Drupal::service('file.usage')
                    ->add($file, 'file', 'shortifys', 'file_ajax');
                $filename = $file->getFileUri();

                return new JsonResponse([
                    'id' => $file->id(),
                    'url' => str_replace($GLOBALS['base_url'], "", file_create_url($filename)),
                ]);
            } else {
                return new JsonResponse(['id' => 0]);
            }
        } else {
            return new JsonResponse(['id' => 0]);
        }
    }

    public function getShortcodesList() : Response
    {
        return new Response(\GuzzleHttp\json_encode(ShortcodeHelper::getDefaultShortcodeList()));
    }
}
